.. expect: default role used (hint: for inline literals, use double backticks) (default-role)
.. expect: default role used (hint: for inline literals, use double backticks) (default-role)

In the following table there are a couple of default roles that should fail:

+-----------------+-------------------------------+----------------------------+
| `French`        | Julien Palard `@JulienPalard` | `GitHub <github_fr_>`_     |
+-----------------+-------------------------------+----------------------------+
